==> nomadic_2025_01_17.zip: nomadic/resources/views/global/userinfo-card.blade.php <==
@if($data)
<div class="row">
  <div class="col-md-6">
    @if($data->profile_pic)
    <img src="{{asset('storage/profile-pic')}}/{{$data->profile_pic}}" class="img-fluid">
    @else
    <img src="{{asset('images/user-img.png')}}" class="img-fluid">
    @endif
  </div>
  <div class="col-md-6">
    <input type="hidden" id="user_uuid" name="user_uuid" value="{{$data->uuid}}" readonly>
    <label class="lblprofile">Name</label>
    <div class="clearboth"></div>
    <label class="lblprofilebind">{{$data->fname}} {{$data->lname}}</label>
    <div class="clearboth"></div>
    <label class="lblprofile mt-4">Phone</label>
    <div class="clearboth"></div>
    <label class="lblprofile">{{$data->mobile_number}}</label>
    <div class="clearboth"></div>
    <label class="lblprofile mt-4">Membership level</label>
    <div class="clearboth"></div>
    <label class="lblprofile">@if($data->user_plan){{$data->user_plan->name}}@endif</label>
  </div>
</div>
<div class="row">
  <div class="col-md-12 mt-5">
    <label class="lblprofile">What is your home city?</label>
      <div class="clearboth"></div>
      <label class="lblprofile">@if(isset($data->user_location->location)){{$data->user_location->location}}@endif</label>
      <div class="clearboth"></div>
      <label class="lblprofile mt-4">What art you are creating?</label>
      <div class="clearboth"></div>
      <label class="lblprofile">{{$creator_interest}}</label>
      <div class="clearboth"></div>
      <label class="lblprofile mt-4">Link to Portfolio</label>
      <div class="clearboth"></div>
      <label class="lblprofile">{{$data->profile_link}}</label>
      <div class="clearboth"></div>
      <label class="lblprofile mt-4">Link to Facebook</label>
      <div class="clearboth"></div>
      <label class="lblprofile">{{$data->facebook_link}}</label>
      <div class="clearboth"></div>
      <label class="lblprofile mt-4">Link to Instagram</label>
      <div class="clearboth"></div>
      <label class="lblprofile">{{$data->instagram_link}}</label>
      <div class="clearboth"></div>
      <label class="lblprofile mt-4">Link to Twitter</label>
      <div class="clearboth"></div>
      <label class="lblprofile">{{$data->twitter_link}}</label>
      <div class="clearboth"></div>
      <label class="lblprofile mt-4">Link to other SM</label>
      <div class="clearboth"></div>
      <label class="lblprofile">{{$data->sm_link}}</label>
      
  </div>
</div>
<div class="row mt-3 usraction">
  @if($data->status==0 || $data->status==1)
  <div class="col-md-4">
    <input type="button" class="btn btnapprove btnappaction w-100 mb-2" data-type="app" data-action="2" value="Approve">
  </div>
  <div class="col-md-4">
    <input type="button" class="btn btnDenied btnappaction w-100 mb-2" data-type="app" data-action="3" value="Deny">
  </div>
  @elseif($data->status==2)
  <span class="txtApproved">Approved</span>
  @elseif($data->status==3)
  <span class="txtDenied">Denied</span>
  @endif
</div>
@else
<div align="center">No data found</div>
@endif

==> nomadic_2025_07_19.zip: nomadic/resources/views/global/userinfo-card.blade.php <==
@if($data)
<div class="row">
  <div class="col-md-6">
    @if($data->profile_pic)
    <img src="{{asset('storage/profile-pic')}}/{{$data->profile_pic}}" class="img-fluid">
    @else
    <img src="{{asset('images/user-img.png')}}" class="img-fluid">
    @endif
  </div>
  <div class="col-md-6">
    <input type="hidden" id="user_uuid" name="user_uuid" value="{{$data->uuid}}" readonly>
    <label class="lblprofile">Name</label>
    <div class="clearboth"></div>
    <label class="lblprofilebind">{{$data->fname}} {{$data->lname}}</label>
    <div class="clearboth"></div>
    <label class="lblprofile mt-4">Phone</label>
    <div class="clearboth"></div>
    <label class="lblprofile">{{$data->mobile_number}}</label>
    <div class="clearboth"></div>
    <label class="lblprofile mt-4">Membership level</label>
    <div class="clearboth"></div>
    <label class="lblprofile">@if($data->user_plan){{$data->user_plan->name}}@endif</label>
  </div>
</div>
<div class="row">
  <div class="col-md-12 mt-5">
    <label class="lblprofile">What is your home city?</label>
      <div class="clearboth"></div>
      <label class="lblprofile">@if(isset($data->user_location->location)){{$data->user_location->location}}@endif</label>
      <div class="clearboth"></div>
      <label class="lblprofile mt-4">What art you are creating?</label>
      <div class="clearboth"></div>
      <label class="lblprofile">{{$creator_interest}}</label>
      <div class="clearboth"></div>
      <label class="lblprofile mt-4">Link to Portfolio</label>
      <div class="clearboth"></div>
      <label class="lblprofile">{{$data->profile_link}}</label>
      <div class="clearboth"></div>
      <label class="lblprofile mt-4">Link to Facebook</label>
      <div class="clearboth"></div>
      <label class="lblprofile">{{$data->facebook_link}}</label>
      <div class="clearboth"></div>
      <label class="lblprofile mt-4">Link to Instagram</label>
      <div class="clearboth"></div>
      <label class="lblprofile">{{$data->instagram_link}}</label>
      <div class="clearboth"></div>
      <label class="lblprofile mt-4">Link to Twitter</label>
      <div class="clearboth"></div>
      <label class="lblprofile">{{$data->twitter_link}}</label>
      <div class="clearboth"></div>
      <label class="lblprofile mt-4">Link to other SM</label>
      <div class="clearboth"></div>
      <label class="lblprofile">{{$data->sm_link}}</label>
      
  </div>
</div>
<div class="row mt-3 usraction">
  @if($data->status==0 || $data->status==1)
  <div class="col-md-4">
    <input type="button" class="btn btnapprove btnappaction w-100 mb-2 btn-primary" data-type="app" data-action="2" value="Approve">
  </div>
  <div class="col-md-4">
    <input type="button" class="btn btnDenied btnappaction w-100 mb-2 btn-primary" data-type="app" data-action="3" value="Deny">
  </div>
  @elseif($data->status==2)
  <span class="txtApproved">Approved</span>
  @elseif($data->status==3)
  <span class="txtDenied">Denied</span>
  @endif
</div>
@else
<div align="center">No data found</div>
@endif
